@@ -616,7 +616,7 @@ int rsp_register_tags(int                        sd,
          threadSafetyUnlock(&rserpoolSocket->Mutex);
          return(-1);
       }
-      threadSafetyNew(&rserpoolSocket->PoolElement->Mutex, "RspPoolElement");
+      threadSafetyNew(&rserpoolSocket->PoolElement->Mutex, "PoolElement");
       poolHandleNew(&rserpoolSocket->PoolElement->Handle, poolHandle, poolHandleSize);
       timerNew(&rserpoolSocket->PoolElement->ReregistrationTimer,
                &gDispatcher,
@@ -1004,7 +1004,6 @@ int rsp_forcefailover_tags(int                sd,
             if(rserpoolSocket->Socket >= 0) {
                success = true;
                rserpoolSocket->WaitingForFirstMsg = true;
-               rserpoolSocket->ConnectedSession->ConnectionTimeStamp = getMicroTime();
                sessionStorageUpdateSession(&rserpoolSocket->SessionSet,
                                            rserpoolSocket->ConnectedSession,
                                            0);
@@ -1063,8 +1062,14 @@ int rsp_forcefailover_tags(int                sd,
                  "Handle resolution did not find new pool element. Waiting %lluus...\n",
                  rserpoolSocket->ConnectedSession->HandleResolutionRetryDelay);
          LOG_END
-         usleep((unsigned int)rserpoolSocket->ConnectedSession->HandleResolutionRetryDelay);
          errno = ENOENT;
+         // Release lock before waiting with usleep()!
+#ifdef ENABLE_CSP
+         syncSessionStatus(rserpoolSocket, rserpoolSocket->ConnectedSession);
+#endif
+         threadSafetyUnlock(&rserpoolSocket->Mutex);
+         usleep((unsigned int)rserpoolSocket->ConnectedSession->HandleResolutionRetryDelay);
+         return(false);
       }
       else {
          LOG_WARNING
@@ -1080,6 +1085,10 @@ int rsp_forcefailover_tags(int                sd,
       errno = EINVAL;
    }
 
+#ifdef ENABLE_CSP
+   syncSessionStatus(rserpoolSocket, rserpoolSocket->ConnectedSession);
+#endif
+
    threadSafetyUnlock(&rserpoolSocket->Mutex);
    return((success == true) ? 0 : -1);
 }
@@ -1122,6 +1131,7 @@ ssize_t rsp_sendmsg(int                sd,
                  session->SessionID,
                  rserpoolSocket->Descriptor, rserpoolSocket->Socket);
          LOG_END
+         session->PPID = ntohl(sctpPPID);
          result = sendtoplus(rserpoolSocket->Socket, data, dataLength,
 #ifdef MSG_NOSIGNAL
                              msg_flags|MSG_NOSIGNAL,
@@ -1318,7 +1328,7 @@ ssize_t rsp_recvmsg(int                    sd,
          else {
             if(rserpoolSocket->WaitingForFirstMsg) {
                rserpoolSocket->WaitingForFirstMsg = false;
-#ifdef LINUX
+#if defined(__LINUX__)
 #ifdef HAVE_KERNEL_SCTP
 #warning Using lksctp fix for possible bad primary path after connectx()!
 /*
@@ -1748,21 +1758,25 @@ size_t getSessionStatus(struct ComponentAssociation** caeArray,
       while(rserpoolSocket != NULL) {
          session = sessionStorageGetFirstSession(&rserpoolSocket->SessionSet);
          while(session != NULL) {
-            if((!session->IsIncoming) &&
-               (!session->IsFailed)) {
-               (*caeArray)[caeArraySize].ReceiverID = CID_COMPOUND(CID_GROUP_POOLELEMENT, session->ConnectedPE);
-               (*caeArray)[caeArraySize].Duration   = (session->ConnectionTimeStamp > 0) ? (getMicroTime() - session->ConnectionTimeStamp) : ~0ULL;
+            threadSafetyLock(&session->Status.Mutex);
+
+            if((!session->Status.IsIncoming) &&
+               (!session->Status.IsFailed)) {
+               (*caeArray)[caeArraySize].ReceiverID = CID_COMPOUND(CID_GROUP_POOLELEMENT, session->Status.ConnectedPE);
+               (*caeArray)[caeArraySize].Duration   = (session->Status.ConnectionTimeStamp > 0) ? (getMicroTime() - session->Status.ConnectionTimeStamp) : ~0ULL;
                (*caeArray)[caeArraySize].Flags      = 0;
                (*caeArray)[caeArraySize].ProtocolID = rserpoolSocket->SocketProtocol;
-               (*caeArray)[caeArraySize].PPID       = 0;
+               (*caeArray)[caeArraySize].PPID       = session->Status.PPID;
                caeArraySize++;
-               getComponentLocation(componentLocation, rserpoolSocket->Socket, session->AssocID);
+               getComponentLocation(componentLocation, session->Status.Socket, session->Status.AssocID);
             }
             if(session->StatusText[0] != 0x00) {
                safestrcpy(statusText,
-                          session->StatusText,
+                          session->Status.StatusText,
                           CSPR_STATUS_SIZE);
             }
+
+            threadSafetyUnlock(&session->Status.Mutex);
             session = sessionStorageGetNextSession(&rserpoolSocket->SessionSet, session);
          }
          if((rserpoolSocket->PoolElement) &&
